﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using CSrfeReaderInterface.protocol;

namespace CSrfeReaderInterface.rfe.protocol
{
    class CSrfePURprotocolHandler : CSrfeProtocolHandler
    {
        /// <summary>
        /// Constructs an instnace of the protocol handler for the given device.
        /// </summary>
        /// <param name="device">Device to which the reader is connected</param>
        public CSrfePURprotocolHandler(device.IProtocolDeviceInterface device) : base(device)
        {
        }

        #region Tag-Functions

        public bool readFromHandle ( byte[] handle, byte mem_bank, ushort address, byte[] passwd, byte count, out byte[] data )
        {
            data = new byte[0];

            if (passwd.Length != 4){
		        Global.trc(3, "Read From Handle - NOK - Data");
		        return false;
	        }

            byte[] payload;
            List<byte> payloadList = new List<byte>();
	        payloadList.AddRange(handle);

	        payloadList.Add((byte) mem_bank);
	        payloadList.Add((byte) (address >> 8));
	        payloadList.Add((byte) address);
	        payloadList.AddRange(passwd);

	        payloadList.Add(count);
            payload = payloadList.ToArray();

            byte[] resultData;

            if (!customTagCommand((byte)0x05, payload, out resultData))
                return false;

            data = new byte[resultData.Length - 1];
            Array.Copy(resultData, 1, data, 0, resultData.Length - 1);

            return true;
        }

        #endregion
    }
}
